@@ -24,6 +24,7 @@
 #include "../oxygengtkutils.h"
 #include "../config.h"
 #include "../oxygencairocontext.h"
+#include "../oxygencairoutils.h"
 #include "oxygenanimations.h"
 #include "../oxygenstyle.h"
 #include "../oxygenmetrics.h"
@@ -85,6 +86,8 @@ namespace Oxygen
     void InnerShadowData::registerChild( GtkWidget* widget )
     {
 
+        #if ENABLE_INNER_SHADOWS_HACK
+
         // make sure widget is not already in map
         if( _childrenData.find( widget ) != _childrenData.end() ) return;
 
@@ -111,11 +114,14 @@ namespace Oxygen
             _childrenData.insert( std::make_pair( widget, data ) );
         }
 
+        #endif
+
     }
 
     //________________________________________________________________________________
     void InnerShadowData::unregisterChild( GtkWidget* widget )
     {
+        #if ENABLE_INNER_SHADOWS_HACK
 
         ChildDataMap::iterator iter( _childrenData.find( widget ) );
         if( iter == _childrenData.end() ) return;
@@ -130,11 +136,13 @@ namespace Oxygen
         iter->second.disconnect( widget );
         _childrenData.erase( iter );
 
+        #endif
     }
 
     //________________________________________________________________________________
     void InnerShadowData::ChildData::disconnect( GtkWidget* widget )
     {
+        #if ENABLE_INNER_SHADOWS_HACK
 
         // disconnect signals
         _unrealizeId.disconnect();
@@ -153,6 +161,8 @@ namespace Oxygen
         // restore compositing if different from initial state
         if( GDK_IS_WINDOW( window ) && !gdk_window_is_destroyed(window) && gdk_window_get_composited( window ) != _initiallyComposited )
         { gdk_window_set_composited( window, _initiallyComposited ); }
+
+        #endif
     }
 
     //____________________________________________________________________________________________
@@ -172,6 +182,7 @@ namespace Oxygen
     gboolean InnerShadowData::targetExposeEvent( GtkWidget* widget, GdkEventExpose* event, gpointer )
     {
 
+        #if ENABLE_INNER_SHADOWS_HACK
         GtkWidget* child( gtk_bin_get_child( GTK_BIN( widget ) ) );
         GdkWindow* window( gtk_widget_get_window( widget ) );
         GdkWindow* childWindow( gtk_widget_get_window( child ) );
@@ -219,6 +230,40 @@ namespace Oxygen
         cairo_fill(context);
         #endif
 
+        // Render rounded combobox list child
+        if(Gtk::gtk_combobox_is_tree_view( child ))
+        {
+            StyleOptions options(widget,gtk_widget_get_state(widget));
+            Corners corners(CornersAll);
+            if(gtk_widget_get_visible(gtk_scrolled_window_get_vscrollbar(GTK_SCROLLED_WINDOW(widget))))
+            {
+                if(Gtk::gtk_widget_layout_is_reversed( widget ))
+                    corners &= ~CornersLeft;
+                else
+                    corners &= ~CornersRight;
+            }
+            if(gtk_widget_get_visible(gtk_scrolled_window_get_hscrollbar(GTK_SCROLLED_WINDOW(widget))))
+                corners &= ~CornersBottom;
+
+            int x(allocation.x),y(allocation.y),w(allocation.width),h(allocation.height);
+            cairo_rectangle(context,x,y,w,h);
+            if(!Gtk::gdk_default_screen_is_composited())
+            {
+                // Take ugly shadow into account
+                x+=1;
+                y+=1;
+                w-=2;
+                h-=2;
+            }
+            cairo_rounded_rectangle_negative(context,x,y,w,h,2,corners);
+            cairo_clip(context);
+
+            Style::instance().renderMenuBackground( context, allocation.x,allocation.y,allocation.width,allocation.height, options );
+
+            // Event handling finished, now let the event propagate
+            return FALSE;
+        }
+
         // draw the shadow
         /*
         TODO: here child widget's allocation is used instead of window geometry.
@@ -312,6 +357,8 @@ namespace Oxygen
             allocation.x-offsetX, allocation.y-offsetY, allocation.width+offsetX*2, allocation.height+offsetY*2,
             options, data );
 
+        #endif // enable inner shadows hack
+
         // let the event propagate
         return FALSE;
     }
