@@ -65,6 +65,7 @@ namespace Oxygen
         _viewDrawTreeBranchLines( true ),
         _viewDrawTriangularExpander( true ),
         _viewTriangularExpanderSize( ArrowSmall ),
+        _viewInvertSortIndicator( false ),
         _menuHighlightMode( MM_DARK ),
         _windowDragEnabled( true ),
         _windowDragMode( WD_FULL ),
@@ -921,6 +922,9 @@ namespace Oxygen
         else if( expanderSize == "TE_TINY" ) _viewTriangularExpanderSize = ArrowTiny;
         else _viewTriangularExpanderSize = ArrowSmall;
 
+        // invert view sort indicators
+        _viewInvertSortIndicator = _oxygen.getOption( "[Style]", "ViewInvertSortIndicator" ).toVariant<std::string>("false") == "true";
+
         // menu highlight mode
         std::string highlightMode( _oxygen.getOption( "[Style]", "MenuHighlightMode" ).toVariant<std::string>("MM_DARK") );
         if( highlightMode == "MM_SUBTLE" ) _menuHighlightMode = MM_SUBTLE;
@@ -1077,7 +1081,7 @@ namespace Oxygen
 
         // button padding
         _css.setCurrentSection( "GtkButton" );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "3px 2px 2px" ) );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "3px 4px 2px" ) );
 
         // pathbar button margins
         _css.addSection( "GtkPathBar>GtkToggleButton" );
